﻿package {
	
	import flash.display.*;
	import flash.geom.*;

	/**
	* Class for the Table object of the #YOGO Fork LD48 game.
	* @author DrLudos
	*/
	public class Table extends MovieClip {
		
		//-= Props =-
		public var customer:Object; //Current Customer of the Table
		//private var customers:MovieClip; //Inner MovieClip of the various Customers animation
		
		private var waiting:int; //Amount of time the customer have been waiting
		private var eating:int; //Amount of food the customer have been able to eat
		
		private var limit_waiting:int; //Amount of time the current customer can wait
		private var limit_eating:int; //Amount of food the customer have been able to eat
		private var fadingout:Boolean; //Ture if a fading out anim for the customer is playing
		
		//-= Constructor =-
		public function Table() {
			
			//Init vars
			this.customer=null;
			this.customers.gotoAndStop("empty");
			
			this.waiting=0;
			this.eating=0;
			this.limit_waiting=0;
			this.limit_eating=0;
			this.fadingout=false;
		}
		
		//-= Methods =-
		
		//Return whether the table has a customer or not
		public function isEmpty():Boolean {
			return (this.customer == null);
		}
		
		//Return whether the table has a customer and he has done eating his meal
		public function isDone():Boolean {
			return (!isEmpty() && this.eating >= limit_eating && customers.face.alpha == 0);
		}
		
		//Return whether the table has a customer and he is bored from waiting and want to leave
		public function isBored():Boolean {
			return (!isEmpty() && this.waiting >= limit_waiting && customers.face.alpha == 0);
		}
		
		//Set a customer to the table
		public function setCustomer( cust:Object ):void{
			
			//If there is indeed a customer
			if( cust != null ){
			
				//Add the customer to the table
				this.customer = cust;
				
				//And use its limits
				this.limit_waiting = cust.waiting;
				this.limit_eating = cust.eating;
				
				//And resets the current tables vars
				this.waiting=0;
				this.eating=0;
				this.fadingout=false;
				
				//And display the customer face :)
				this.customers.gotoAndStop(cust.face);
			}
			
			//Else the table will be emptied
			else {
				this.customer = null;
				this.customers.gotoAndStop("empty");
				
				this.waiting=0;
				this.eating=0;
				this.limit_waiting=0;
				this.limit_eating=0;
				this.fadingout=false;
			}
		}
		
		//RUNNING LOOP (timer decrease, eating meal...)
		//Param (true if I get the fork)
		public function run( forked:Boolean = false ):void{
			
			//If I got customer
			if( customer != null ){
			
				//If the customer isn't fading out (i.e. when it's still active)
				if (!fadingout){
					
					//Do I get Fork ?
					if ( forked ){
						//My customer can eat :)
						eating++;
						//Relief some waiting from eating
						waiting-= customer.relief;
						if (waiting < 0){ waiting=0; }
						//Play eating anim if it ain't the case
						if ( this.customers.face.currentAnim != "eating" ){
							this.customers.face.gotoAndPlay("eating");
						}
						//Play sound
						(this.parent as MovieClip).playSFX("sfx_eat",false,0,0.4);
					}
					//Esle I'm forkless
					else {
						//My customer is waiting :(
						waiting++;
						//Play waiting anim if it ain't the case
						if ( this.customers.face.currentAnim != "waiting" ){
							this.customers.face.gotoAndPlay("waiting");
						}
					}
					
					//Update the bars to reflect eating and waiting time
					//Waiting Time = waiting (little num) / waiting limit (big num) * 100 (except that scale is 0-1, so *100 isn't need
					//The waiting bar is reversed (from 100 to 0) for readiness purposes
					customers.bar_waiting.jauge.scaleX=1 - (waiting / limit_waiting);
					
					//Change the bar color depending on its value
					var tmp:ColorTransform=new ColorTransform();
					if( customers.bar_waiting.jauge.scaleX < 0.3 ){ tmp.color=0xFF0000; }
					else if( customers.bar_waiting.jauge.scaleX < 0.6 ){ tmp.color=0xFF6600; }
					else { tmp.color=0x00FF00; }
					customers.bar_waiting.jauge.transform.colorTransform=tmp;
					
					//The eating bar is the rice bowl animatin inside each chars (fading on 50 frames)
					//customers.bar_eating.jauge.scaleX= eating / limit_eating;
					customers.face.food.gotoAndStop( Math.ceil(eating / limit_eating * 50) );
					
					//Lance les anims de perte et victoire si nécéssaire (
					//elle font aussi un fading out du perso, qui doit avoir l'alpha à 0 pour que le jeu "libère" la table
					if( this.waiting >= limit_waiting && !fadingout ){
						customers.face.gotoAndPlay("bored");
						this.fadingout = true;
						//Play sound
						(this.parent as MovieClip).playSFX("sfx_sad",false,0,0.5);
					}
					if( this.eating >= limit_eating && !fadingout ){			
						customers.face.gotoAndPlay("done");
						this.fadingout = true;
						//Play sound
						(this.parent as MovieClip).playSFX("sfx_happy",false,0,0.6);
					}
				}
			}
		}
		
	}
}